#pragma once

#include <Base_Packet.h>

namespace inaf::oasbo::Packets {

/**
 * @brief Represents a generic ASTRI horn packet.
 * @note the "magic numbers" in the implementation of this class derived from the ASTRI Camera BEE – Camera Camera Data Acquisition
 * Interface Control Document.
 * If the document is updated, be sure to update the magic numbers appropriately. 
 * This class inherits from the BasePacket class and provides
 * functionality specific to ASTRI horn packets.
 */
class AstriHornGeneric: public inaf::oasbo::Packets::BasePacket {

public:
	/**
	 * @brief Constructs an AstriHornGeneric object with the given packet structure.
	 * 
	 * @param structure The packet structure to be used.
	 */
	AstriHornGeneric(inaf::oasbo::Packets::BasePacketStructure &structure) :
			BasePacket(structure) {
	}

	/**
	 * @brief Gets the size of the header in bytes.
	 * 
	 * @return The size of the header.
	 */
	uint getHeaderSize() const override;

	/**
	 * @brief Gets the size of the payload in bytes.
	 * 
	 * @return The size of the payload.
	 */
	uint getPayloadSize() const override;

	/**
	 * @brief Gets the size of the tail in bytes.
	 * 
	 * @return The size of the tail.
	 */
	uint getTailSize() const override;

	/**
	 * @brief Checks if the packet has a recognized header.
	 * 
	 * @return True if the packet has a recognized header, false otherwise.
	 */
	bool hasRecognizedHeader() const override;

	/**
	 * @brief Checks if the given buffer contains a recognized header.
	 * 
	 * @param buff The buffer to check.
	 * @return True if the buffer contains a recognized header, false otherwise.
	 */
	bool isRecognizedHeader(std::vector<uint8_t> buff) const override;
};

}
